buffet: Remove 'chromeos' namespace and move everything to buffet NS

As discussed, moved all the classes out of chromeos namespace into
'buffet.

Also fixed a number of cpplint's warnings.

BUG=None
TEST=Everything still compiles and unit tests succeed.

Change-Id: Ide864acb2504627404966727f66d353af60e531d
Reviewed-on: https://chromium-review.googlesource.com/198971
Reviewed-by: Christopher Wiley <wiley@chromium.org>
Commit-Queue: Alex Vakulenko <avakulenko@chromium.org>
Tested-by: Alex Vakulenko <avakulenko@chromium.org>
diff --git a/buffet/string_utils.cc b/buffet/string_utils.cc
index c5d06eb..e122355 100644
--- a/buffet/string_utils.cc
+++ b/buffet/string_utils.cc
@@ -6,9 +6,11 @@
 
 #include <algorithm>
 #include <string.h>
+#include <utility>
+
 #include <base/strings/string_util.h>
 
-namespace chromeos {
+namespace buffet {
 namespace string_utils {
 
 std::vector<std::string> Split(const std::string& str,
@@ -33,7 +35,8 @@
   }
 
   if (trim_whitespaces) {
-    std::for_each(tokens.begin(), tokens.end(), [](std::string& str) {
+    std::for_each(tokens.begin(), tokens.end(),
+                  [](std::string& str) {  // NOLINT(runtime/references)
       TrimWhitespaceASCII(str, TRIM_ALL, &str); });
   }
 
@@ -83,5 +86,5 @@
   return str1 + delimiter + str2;
 }
 
-} // namespace string_utils
-} // namespace chromeos
+}  // namespace string_utils
+}  // namespace buffet